==> layoutlib-api-26.6.4-sources.jar: com/android/resources/HighDynamicRange.java <==
/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.resources;

/**
 * High Dynamic Range
 *
 * <p>This is used in the resource folder names.
 */
public enum HighDynamicRange implements ResourceEnum {
    HIGHDR("highdr", "High Dynamic Range", "High Dynamic Rage"),
    LOWDR("lowdr", "Low Dynamic Range", "Low Dynamic Range");

    private final String mValue;
    private final String mShortDisplayValue;
    private final String mLongDisplayValue;

    HighDynamicRange(String value, String displayValue, String longDisplayValue) {
        mValue = value;
        mShortDisplayValue = displayValue;
        mLongDisplayValue = longDisplayValue;
    }

    /**
     * Returns the enum for matching the provided qualifier value.
     *
     * @param value The qualifier value.
     * @return the enum for the qualifier value or null if no matching was found.
     */
    public static HighDynamicRange getEnum(String value) {
        for (HighDynamicRange orient : values()) {
            if (orient.mValue.equals(value)) {
                return orient;
            }
        }

        return null;
    }

    @Override
    public String getResourceValue() {
        return mValue;
    }

    @Override
    public String getShortDisplayValue() {
        return mShortDisplayValue;
    }

    @Override
    public String getLongDisplayValue() {
        return mLongDisplayValue;
    }

    public static int getIndex(HighDynamicRange value) {
        return value == null ? -1 : value.ordinal();
    }

    public static HighDynamicRange getByIndex(int index) {
        HighDynamicRange[] values = values();
        if (index >= 0 && index < values.length) {
            return values[index];
        }
        return null;
    }

    @Override
    public boolean isFakeValue() {
        return false;
    }

    @Override
    public boolean isValidValueForDevice() {
        return true;
    }
}

==> layoutlib-api-31.5.0-sources.jar: com/android/resources/HighDynamicRange.java <==
/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.resources;

/**
 * High Dynamic Range
 *
 * <p>This is used in the resource folder names.
 */
public enum HighDynamicRange implements ResourceEnum {
    HIGHDR("highdr", "High Dynamic Range", "High Dynamic Range"),
    LOWDR("lowdr", "Low Dynamic Range", "Low Dynamic Range");

    private final String mValue;
    private final String mShortDisplayValue;
    private final String mLongDisplayValue;

    HighDynamicRange(String value, String displayValue, String longDisplayValue) {
        mValue = value;
        mShortDisplayValue = displayValue;
        mLongDisplayValue = longDisplayValue;
    }

    /**
     * Returns the enum for matching the provided qualifier value.
     *
     * @param value The qualifier value.
     * @return the enum for the qualifier value or null if no matching was found.
     */
    public static HighDynamicRange getEnum(String value) {
        for (HighDynamicRange orient : values()) {
            if (orient.mValue.equals(value)) {
                return orient;
            }
        }

        return null;
    }

    @Override
    public String getResourceValue() {
        return mValue;
    }

    @Override
    public String getShortDisplayValue() {
        return mShortDisplayValue;
    }

    @Override
    public String getLongDisplayValue() {
        return mLongDisplayValue;
    }

    public static int getIndex(HighDynamicRange value) {
        return value == null ? -1 : value.ordinal();
    }

    public static HighDynamicRange getByIndex(int index) {
        HighDynamicRange[] values = values();
        if (index >= 0 && index < values.length) {
            return values[index];
        }
        return null;
    }

    @Override
    public boolean isFakeValue() {
        return false;
    }

    @Override
    public boolean isValidValueForDevice() {
        return true;
    }
}
